﻿using System;
using System.Windows;
using System.Windows.Data;

namespace UserStageExample.ValueConverters
{
    /// <summary>
    /// Конвертер булевых значений в видимость элемента
    /// </summary>
    internal class BooleanToVisibilityConverter : IValueConverter
    {
        /// <summary>
        /// Преобразует булево значение в тип видимости
        /// </summary>
        /// <param name="value">Исходное значение</param>
        /// <param name="targetType">Результирующий тип</param>
        /// <param name="parameter">Не используется</param>
        /// <param name="culture">Не используется</param>
        /// <returns></returns>
        public object Convert(object value, Type targetType, object parameter, System.Globalization.CultureInfo culture)
        {
            if (value is bool && (bool)value)
            {
                return Visibility.Visible;
            }
            return Visibility.Collapsed;
        }

        /// <summary>
        /// Преобразует тип видимости в булево значение
        /// </summary>
        /// <param name="value">Тип видимости</param>
        /// <param name="targetType">Результирующий тип</param>
        /// <param name="parameter">Не используется</param>
        /// <param name="culture">Не используется</param>
        /// <returns></returns>
        public object ConvertBack(object value, Type targetType, object parameter, System.Globalization.CultureInfo culture)
        {
            return value is Visibility && (Visibility)value == Visibility.Visible;
        }
    }
}
