﻿using System;
using System.Collections.Generic;
using System.Globalization;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Data;

namespace UserStageExample.ValueConverters
{
    /// <summary>
    /// Конвертер перечислений
    /// </summary>
    /// <remarks>
    /// Позволяет конвертировать перечисления в значения Visiblity или в bool
    /// Также позволяет конвертировать bool в значения перечислений
    /// </remarks>
    internal class EnumConverter : IValueConverter
    {
        /// <summary>
        /// Конвертирует Значение перечисления в булевый тип
        /// </summary>
        /// <param name="value">Значение</param>
        /// <param name="targetType">Результирующий тип: Visiblity или bool</param>
        /// <param name="parameter">Сравниваемое значение (в виде строки ли как есть)</param>
        /// <param name="culture">Не играет роли</param>
        /// <returns></returns>
        public object Convert(object value, Type targetType, object parameter, CultureInfo culture)
        {
            var target = parameter.GetType() == value.GetType() ? parameter : Enum.Parse(value.GetType(), parameter.ToString());
            var equals = value.Equals(target);
            if (targetType == typeof(bool) || targetType == typeof(bool?))
                return equals;
            return equals ? Visibility.Visible : Visibility.Hidden;
        }

        /// <summary>
        /// Преобразовывает булевую величину в тип перечисления
        /// </summary>
        /// <remarks>
        /// Можно использовать с радио-кнопками
        /// </remarks>
        /// <param name="value">Булево значение</param>
        /// <param name="targetType">Тип перечисления</param>
        /// <param name="parameter">Значение перечисления, которое должно быть установлено если value == true</param>
        /// <param name="culture">Не используется</param>
        /// <returns></returns>
        public object ConvertBack(object value, Type targetType, object parameter, CultureInfo culture)
        {
            var target = parameter.GetType() == value.GetType() ? parameter : Enum.Parse(targetType, parameter.ToString());
            if ((bool)value) return target;
            return null;
        }
    }
}
