﻿using System;
using System.ComponentModel;
using System.IO;
using System.Runtime.CompilerServices;

namespace UserStageExample.ViewModel
{
    /// <summary>
    /// Тип аутентификации
    /// </summary>
    internal enum AuthType
    {
        /// <summary>
        /// Аутентификация FlexiCapture
        /// </summary>
        FlexiCapture,

        /// <summary>
        /// Windows аутентификация
        /// </summary>
        Windows
    }

    /// <summary>
    /// Контроллер аутентификации
    /// </summary>
    internal class AuthViewModel : INotifyPropertyChanged
    {
        /// <summary>
        /// URL сервера
        /// </summary>
        private string _serverUri;
        /// <summary>
        /// Тип аутентификации
        /// </summary>
        private AuthType _authType = AuthType.Windows;

        private string _login;
        private string _loginResult;
        private readonly string _configFile;
        public event PropertyChangedEventHandler PropertyChanged;

        public string ServerUri
        {
            get { return _serverUri; ; }
            set { _serverUri = value; OnPropertyChanged(); }
        }

        public AuthType AuthType
        {
            get { return _authType; }
            set { _authType = value; OnPropertyChanged(); }
        }

        public string Login
        {
            get { return _login; }
            set { _login = value; OnPropertyChanged(); }
        }
        public string LoginResult
        {
            get { return _loginResult; }
            set { _loginResult = value; OnPropertyChanged(); }
        }

        public AuthViewModel()
        {
            var dir = Environment.GetFolderPath(Environment.SpecialFolder.ApplicationData);
            _configFile = Path.Combine(dir, "service_step.dat");
            if (!File.Exists(_configFile)) return;
            var content = File.ReadAllLines(_configFile);
            if (content.Length < 2) return;
            _serverUri = content[0];
            _login = content[1];
            Enum.TryParse(content[2], out _authType);
        }

        public void Save()
        {
            File.WriteAllText(_configFile, _serverUri + Environment.NewLine 
                + _login + Environment.NewLine
                + _authType + Environment.NewLine
                );
        }

        protected virtual void OnPropertyChanged([CallerMemberName] string propertyName = null)
        {
            var h = PropertyChanged;
            if (h != null) h.Invoke(this, new PropertyChangedEventArgs(propertyName));
        }
    }
}
